@@ -58,6 +58,14 @@ class YAPENVConfigRequirement(CascadingConfigDictionary):
 
 
 class YAPENVConfig(CascadingConfig):
+    RESOLVE_PATH_KEYS = [
+        "pip_config_path",
+        "env_file",
+    ]
+    """A collection of configuration keys to resolve as paths. The resolve will be called relative
+    to the location of the config file.
+    """
+
     @property
     def env_file(self) -> str:
         return self.get("env_file", ".env")
@@ -122,6 +130,10 @@ class YAPENVConfig(CascadingConfig):
     def initialize(self, environment: str = None):
         super().initialize(environment)
 
+        for key in self.RESOLVE_PATH_KEYS:
+            if isinstance(self.get(key, None), str):
+                self[key] = self.resolve_from_source_directory(self[key])
+
         # Resolve the requirement for absolute imports. This is to allow
         # requirements to have the proper relative path to the source.
         for requirement in self.requirements:
@@ -154,6 +166,7 @@ class YAPENVConfig(CascadingConfig):
                 resolved_requirements.append(req)
 
         self[REQUIREMENTS_COLLECTION_NAME] = resolved_requirements
+        self.clean_requirements()
 
     def load_virtualenv(self):
         """Loads the virtual environment into python (using activate.py)."""
@@ -169,6 +182,11 @@ class YAPENVConfig(CascadingConfig):
         """Clean the requirement list for all environments and remove duplicates"""
         requirement_configs = [self, *self.environments.values()]
 
+        # Resolve to relative the base path keys
+        for key in self.RESOLVE_PATH_KEYS:
+            if isinstance(self.get(key, None), str):
+                self[key] = os.path.relpath(self[key], self.source_directory)
+
         # First resolve to relative
         req_config: YAPENVConfig = None
         for req_config in requirement_configs:
